import { Logger, Service } from 'homebridge';
/**
 * This class is the API via websocket to the Pronet web gateway.
 */
export declare class SentiotecAPI {
    /**
     * the logger that should be used
     */
    private log;
    /**
     * the map of cached values
     */
    private cachedValues;
    /**
     * indicates that a data update is needed
     */
    dataExpired: boolean;
    /**
     * indicates that a data refresh is currently in progress
     */
    private dataUpdateInProgress;
    /**
     * indicates if a/the Sauna is actually connected to the pronet unit
     */
    connected: boolean;
    /**
     * the constructor
     * @param log the logger to be used
     */
    constructor(log: Logger);
    /**
     * This function creates a new websocket and authenticates the user based on the information given in the constructor
     * @param ip the IP of the pronet gatway
     * @param password the password for login
     * @param serial the serial number of the gateway
     * @param log the logger to output status messages
     * @returns a Promise with the created and authenticated websocket
     */
    private connect;
    /**
     * This function refreshes all characteristics.
     * @param saunaID the number of the sauna in question
     * @param websocket the open websocket
     * @param log the logger to output status messages
     * @returns a Promise that after all have been refreshed
     */
    private querySaunaParameters;
    /**
     * This function refreshes all characteristics of the sauna.
     * @param saunaID the ID of the sauna (either 0 for Sauna 1 oder 1 for Sauna 2)
     * @param characteristicID the ID of the characteristic
     * @returns the value
     */
    refreshCharacteristics(saunaID: number, characteristicID: number, ip: string, password: string, serial: string, log: Logger): Promise<undefined>;
    /**
     * This function fetches a characteristic from cached map. In case it does not exist an empty string is returned.
     * @param saunaID the ID of the sauna
     * @param characteristicID the ID of the characteristic
     */
    getCachedCharacteristic(service: Service, saunaID: number, characteristicID: number): string;
}
//# sourceMappingURL=websocket.d.ts.map